#include <QSqlError>
#include <QTreeWidgetItem>
#include <QMessageBox>
#include "AlarmHistoryTree.h"
#include "mysqlmodel.h"
#include <QHeaderView>
#include <QtDebug>
#include <QApplication>
#include <QCoreApplication>
#include <macros.h>

AlarmHistoryTree::AlarmHistoryTree(QWidget *parent) : QTreeView(parent)
{
	db = QSqlDatabase::addDatabase("QMYSQL");
	QStringList args = qApp->arguments();
	QString dbHost = "log";
	if(args.contains("--log-database-host") && args.size() > args.indexOf("--log-database-host"))
	{
	  dbHost = args.at(args.indexOf("--log-database-host") + 1);
	  //qDebug()<<"Database host: "<<dbHost;
	}
    db.setHostName(dbHost);
	db.setDatabaseName("alarm");
	db.setUserName("alarm-client");
	db.setPassword("");
        if (!db.open())
	{
		QString sqlErr = db.lastError().text();
                QMessageBox::critical(0, "Error", QString("Can't establish connection with db \"alarm\" on host log:\n%1").arg(sqlErr));

	}
	model = new MySqlModel();
	model->setHeaderData(0, Qt::Horizontal, "Timestamp");
	setModel(model);
}

void AlarmHistoryTree::updateView(QString &s)
{

}

void AlarmHistoryTree::applyFilter(AlarmFilter f)
{   
	int i, j;
	QList<QVariant> rowEls;	
	if(_filter_enabled)
		removeFilter();

	int rowCount = model->rowCount();
	int colCount = model->columnCount();
	QModelIndex root = rootIndex();

	for(i = 0; i < rowCount; i++)
	{
		rowEls.clear();
		for(j = 0; j < colCount; j++)
			rowEls << model->data(model->index(i, j),  Qt::DisplayRole);

		if(f.ack_enable)
		{
			QString sack = f.ack ? "ACK" : "NACK";
			if(rowEls.size() > ACK && rowEls[ACK] != sack)
				setRowHidden(i, root, true);
		}

		if(f.lev)
		{
			/* must not have been hidden previously */
			if(rowEls.size() > LEVEL && rowEls[LEVEL] != f.level && !isRowHidden(i, root))
				setRowHidden(i, root, true);
		}

		if(f.stat)
		{
			/* must not have been hidden previously */
			if(rowEls.size() > STATUS && rowEls[STATUS] != f.status && !isRowHidden(i, root))
				setRowHidden(i, root, true);
		}

		if(f.grp)
		{
			/* must not have been hidden previously */
			for(int k = 0; k < f.groups.size(); k++)
			{
				if(rowEls.size() > GROUP && rowEls[GROUP].canConvert(QVariant::String) && !rowEls[GROUP].toString().
					contains(f.groups[k]) && !isRowHidden(i, root))
				{
					setRowHidden(i, root, true);
					break;
				}
			}
		}
	}
	_filter_enabled = true;

}

void AlarmHistoryTree::removeFilter()
{
        int i;
	
	QModelIndex root = rootIndex();

	for(i = 0; i < model->rowCount(); i++)
	{
		if(isRowHidden(i, root))
			setRowHidden(i, root, false);
	}
        _filter_enabled = false;
        //  headerItem()->setIcon(ACK, QIcon(ICON_PATH + ""));
        //  headerItem()->setIcon(LEVEL, QIcon(ICON_PATH + ""));
        //  headerItem()->setIcon(STATUS, QIcon(ICON_PATH + ""));
        //  headerItem()->setIcon(GROUP, QIcon(ICON_PATH + ""));
}

void AlarmHistoryTree::executeQuery(QString &q)
{
	if (!db.isOpen())
	{
                if (!db.open())
                {
                        QMessageBox::critical(0, "Error", "Can't establish connection with db Alarm on host log");
                        return;
                }
	}
	model->setQuery(q);
	QSqlError error = model->lastError();
        if (error.type() != QSqlError::NoError)
        {
                QMessageBox::critical(0, "Database Error", QString("Error reading from Db:\n") + error.text() + "\nreconnecting");
                db.close();
                if (!db.open())
                {
                        QMessageBox::critical(0, "Error", "Can't establish connection with db FastInterlock on host log");
                        return;
                }
        }
	for(int i = 0; i < header()->count(); i++)
	{
		resizeColumnToContents(i);
		header()->setSortIndicator(i, Qt::AscendingOrder);
	}
}

